@@ -73,7 +73,7 @@ module.exports = {
       // Support React Native Web
       // https://www.smashingmagazine.com/2016/08/a-glimpse-into-the-future-with-react-native-for-web/
       'react-native': 'react-native-web',
-      'ovirtapi': `${paths.appSrc}/ovirtapi/index.js`,
+      ...webpackConfigCommons.commonAliases()
     },
   },
   // Resolve loaders (webpack plugins for CSS, images, transpilation) from the
@@ -91,6 +91,9 @@ module.exports = {
         test: /\.(js|jsx)$/,
         loader: 'eslint',
         include: paths.appSrc,
+        options: {
+          failOnError: true,
+        }
       },
     ],
     loaders: [
