@@ -5,12 +5,14 @@ import {
   LOGIN_SUCCESSFUL,
   LOGOUT,
   SET_ADMINISTRATOR,
+  SET_CURRENT_PAGE,
   SET_DOMAIN,
   SET_OVIRT_API_VERSION,
   SET_USB_FILTER,
   SET_USER_FILTER_PERMISSION,
+  SET_USER_GROUPS,
   SHOW_TOKEN_EXPIRED_MSG,
-} from '../constants'
+} from '_/constants'
 
 const initialState = Immutable.fromJS({
   loginToken: undefined,
@@ -28,6 +30,9 @@ const initialState = Immutable.fromJS({
   isFilterChecked: false,
   administrator: false,
   usbFilter: null,
+  userGroups: [],
+  currentPage: {},
+  blankTemplateId: '00000000-0000-0000-0000-000000000000', // "engine/api/" -> special_objects.blank_template.id
 })
 
 const config = actionReducer(initialState, {
@@ -58,6 +63,12 @@ const config = actionReducer(initialState, {
   [SET_USB_FILTER] (state, { payload: { usbFilter } }) {
     return state.set('usbFilter', usbFilter)
   },
+  [SET_USER_GROUPS] (state, { payload: { groups } }) {
+    return state.set('userGroups', groups)
+  },
+  [SET_CURRENT_PAGE] (state, { payload }) {
+    return state.set('currentPage', Object.assign({}, payload))
+  },
 }, true)
 
 export default config
