@@ -3,9 +3,10 @@ import React from 'react'
 import AddVmButton from './components/VmDialog/AddVmButton'
 import PageRouter from './components/PageRouter'
 import { VmDetailToolbar, PoolDetailToolbar } from './components/Toolbar'
-import { PoolDetailsPage, VmEditPage, VmCreatePage, VmsPage, LegacyVmDetailsPage } from './components/Pages'
+import { PoolDetailsPage, VmDetailsPage, VmCreatePage, VmsPage } from './components/Pages'
 
-import { msg } from './intl'
+import { msg } from '_/intl'
+import { DETAIL_PAGE_TYPE, DIALOG_PAGE_TYPE, MAIN_PAGE_TYPE, POOL_PAGE_TYPE } from '_/constants'
 
 /**
  * Function get vms object, and return routes object
@@ -28,6 +29,7 @@ export default function getRoutes (vms) {
         exact: true,
         component: VmsPage,
         toolbars: [() => (<AddVmButton key='addbutton' id={`route-add-vm`} />)],
+        type: MAIN_PAGE_TYPE,
       },
 
       {
@@ -35,24 +37,17 @@ export default function getRoutes (vms) {
         exact: true,
         title: () => msg.addNewVm(),
         component: VmCreatePage,
-        toolbars: [], // TODO: Recently not used. When needed, see VmDialog/style.css - .vm-dialog-buttons
+        toolbars: [], // TODO: When needed, see VmDialog/style.css - .vm-dialog-buttons
         closeable: true,
+        type: DIALOG_PAGE_TYPE,
       },
 
       {
         path: '/vm/:id',
         title: (match, vms) => vms.getIn(['vms', match.params.id, 'name']) || match.params.id,
-        component: LegacyVmDetailsPage,
+        component: VmDetailsPage,
         toolbars: [(match) => (<VmDetailToolbar match={match} key='vmaction' />)],
-        routes: [
-          {
-            path: '/vm/:id/edit',
-            title: (match) => msg.edit() || match.params.id,
-            component: VmEditPage,
-            toolbars: [], // TODO: Recently not used. When needed, see VmDialog/style.css - .vm-dialog-buttons
-            closeable: true,
-          },
-        ],
+        type: DETAIL_PAGE_TYPE,
       },
 
       {
@@ -60,6 +55,7 @@ export default function getRoutes (vms) {
         title: (match, vms) => vms.getIn(['pools', match.params.id, 'name']) || match.params.id,
         component: PoolDetailsPage,
         toolbars: [(match) => (<PoolDetailToolbar match={match} key='poolaction' />)],
+        type: POOL_PAGE_TYPE,
       },
     ],
   }]
