@@ -1,5 +1,5 @@
 import Product from '../version'
-import Api from 'ovirtapi'
+import Api from '_/ovirtapi'
 import AppConfiguration from '../config'
 import OptionsManager from '../optionsManager'
 import Selectors from '../selectors'
@@ -24,20 +24,22 @@ import {
   setAdministrator,
   getOption,
 
-  getByPage,
-  getAllTemplates,
-  getAllStorageDomains,
   getAllClusters,
   getAllHosts,
   getAllOperatingSystems,
+  getAllStorageDomains,
+  getAllTemplates,
   getAllVnicProfiles,
+  getByPage,
+  getIsoFiles,
+  getUserGroups,
 
   downloadConsole,
   getUSBFilter,
   getSingleVm,
 
   updateVms,
-} from '../actions'
+} from '_/actions'
 
 import {
   callExternalAction,
@@ -179,20 +181,29 @@ function* autoConnectCheck () {
     } else if (vm && vm.id && vm.status !== 'down') {
       const internalVm = Api.vmToInternal({ vm })
       yield put(updateVms({ vms: [internalVm] }))
-      yield downloadVmConsole(downloadConsole({ vmId }))
+      yield downloadVmConsole(downloadConsole({ vmId, hasGuestAgent: internalVm.ssoGuestAgent }))
     }
   }
 }
 
 function* initialLoad () {
-  yield put(getAllClusters()) // no shallow
-  yield put(getAllHosts())
+  yield put(getUserGroups())
+
+  // no requirements
   yield put(getAllOperatingSystems())
   yield put(getAllTemplates({ shallowFetch: false }))
+  yield put(getAllHosts())
   yield put(getAllStorageDomains())
+
+  // requires user groups to be in redux store for authorization checks
+  yield put(getAllClusters())
   yield put(getAllVnicProfiles())
 
-  yield put(getByPage({ page: 1 })) // first page of VMs list
+  // requires storage domains to be in redux store
+  yield put(getIsoFiles())
+
+  // --- store is populated with user & system info, now pull VMs and Pools
+  yield put(getByPage({ page: 1 }))
 }
 
 function* fetchPermissionWithoutFilter () {
